# tutompy
[![Tests](https://github.com/pamlinux/tutompy/workflows/Tests/badge.svg)](https://github.com/pamlinux/tutompy/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/pamlinux/tutompy/branch/master/graph/badge.svg)](https://codecov.io/gh/pamlinux/tutompy)
My repository for hypermodern-python tutorial by Claudio Jolowicz
